# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.cogneed_waveform.services import waveform_loading_pb2 as cogneed__protos_dot_cogneed__waveform_dot_services_dot_waveform__loading__pb2


class WaveformLoadingServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.load = channel.unary_unary(
        '/ai.cogneed.cloud.speech.v1.WaveformLoadingService/load',
        request_serializer=cogneed__protos_dot_cogneed__waveform_dot_services_dot_waveform__loading__pb2.WaveformLoadRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_cogneed__waveform_dot_services_dot_waveform__loading__pb2.WaveformLoadResponse.FromString,
        )


class WaveformLoadingServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def load(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_WaveformLoadingServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'load': grpc.unary_unary_rpc_method_handler(
          servicer.load,
          request_deserializer=cogneed__protos_dot_cogneed__waveform_dot_services_dot_waveform__loading__pb2.WaveformLoadRequest.FromString,
          response_serializer=cogneed__protos_dot_cogneed__waveform_dot_services_dot_waveform__loading__pb2.WaveformLoadResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.cloud.speech.v1.WaveformLoadingService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-ks/services/auth_forward_audio.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.cogneed_ks.services import forward_audio_pb2 as cogneed__protos_dot_cogneed__ks_dot_services_dot_forward__audio__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-ks/services/auth_forward_audio.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n;cogneed-protos/cogneed-ks/services/auth_forward_audio.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\x1a\x36\x63ogneed-protos/cogneed-ks/services/forward_audio.proto\"h\n\x17\x41uthForwardAudioRequest\x12>\n\x05\x61udio\x18\x01 \x01(\x0b\x32/.ai.cogneed.cloud.speech.v1.ForwardAudioRequest\x12\r\n\x05token\x18\x02 \x01(\t2\x8f\x01\n\x17\x41uthForwardAudioService\x12t\n\x07\x66orward\x12\x33.ai.cogneed.cloud.speech.v1.AuthForwardAudioRequest\x1a\x30.ai.cogneed.cloud.speech.v1.ForwardAudioResponse(\x01\x30\x01\x42\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_cogneed__ks_dot_services_dot_forward__audio__pb2.DESCRIPTOR,])




_AUTHFORWARDAUDIOREQUEST = _descriptor.Descriptor(
  name='AuthForwardAudioRequest',
  full_name='ai.cogneed.cloud.speech.v1.AuthForwardAudioRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio', full_name='ai.cogneed.cloud.speech.v1.AuthForwardAudioRequest.audio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='ai.cogneed.cloud.speech.v1.AuthForwardAudioRequest.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=251,
)

_AUTHFORWARDAUDIOREQUEST.fields_by_name['audio'].message_type = cogneed__protos_dot_cogneed__ks_dot_services_dot_forward__audio__pb2._FORWARDAUDIOREQUEST
DESCRIPTOR.message_types_by_name['AuthForwardAudioRequest'] = _AUTHFORWARDAUDIOREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AuthForwardAudioRequest = _reflection.GeneratedProtocolMessageType('AuthForwardAudioRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHFORWARDAUDIOREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.auth_forward_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.AuthForwardAudioRequest)
  ))
_sym_db.RegisterMessage(AuthForwardAudioRequest)


DESCRIPTOR._options = None

_AUTHFORWARDAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='AuthForwardAudioService',
  full_name='ai.cogneed.cloud.speech.v1.AuthForwardAudioService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=254,
  serialized_end=397,
  methods=[
  _descriptor.MethodDescriptor(
    name='forward',
    full_name='ai.cogneed.cloud.speech.v1.AuthForwardAudioService.forward',
    index=0,
    containing_service=None,
    input_type=_AUTHFORWARDAUDIOREQUEST,
    output_type=cogneed__protos_dot_cogneed__ks_dot_services_dot_forward__audio__pb2._FORWARDAUDIORESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTHFORWARDAUDIOSERVICE)

DESCRIPTOR.services_by_name['AuthForwardAudioService'] = _AUTHFORWARDAUDIOSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-waveform/services/waveform_loading.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-waveform/services/waveform_loading.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n?cogneed-protos/cogneed-waveform/services/waveform_loading.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\"!\n\x13WaveformLoadRequest\x12\n\n\x02id\x18\x01 \x01(\t\"%\n\x14WaveformLoadResponse\x12\r\n\x05peaks\x18\x01 \x03(\x05\x32\x83\x01\n\x16WaveformLoadingService\x12i\n\x04load\x12/.ai.cogneed.cloud.speech.v1.WaveformLoadRequest\x1a\x30.ai.cogneed.cloud.speech.v1.WaveformLoadResponseB\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
)




_WAVEFORMLOADREQUEST = _descriptor.Descriptor(
  name='WaveformLoadRequest',
  full_name='ai.cogneed.cloud.speech.v1.WaveformLoadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.cogneed.cloud.speech.v1.WaveformLoadRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=128,
)


_WAVEFORMLOADRESPONSE = _descriptor.Descriptor(
  name='WaveformLoadResponse',
  full_name='ai.cogneed.cloud.speech.v1.WaveformLoadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peaks', full_name='ai.cogneed.cloud.speech.v1.WaveformLoadResponse.peaks', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=167,
)

DESCRIPTOR.message_types_by_name['WaveformLoadRequest'] = _WAVEFORMLOADREQUEST
DESCRIPTOR.message_types_by_name['WaveformLoadResponse'] = _WAVEFORMLOADRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WaveformLoadRequest = _reflection.GeneratedProtocolMessageType('WaveformLoadRequest', (_message.Message,), dict(
  DESCRIPTOR = _WAVEFORMLOADREQUEST,
  __module__ = 'cogneed_protos.cogneed_waveform.services.waveform_loading_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.WaveformLoadRequest)
  ))
_sym_db.RegisterMessage(WaveformLoadRequest)

WaveformLoadResponse = _reflection.GeneratedProtocolMessageType('WaveformLoadResponse', (_message.Message,), dict(
  DESCRIPTOR = _WAVEFORMLOADRESPONSE,
  __module__ = 'cogneed_protos.cogneed_waveform.services.waveform_loading_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.WaveformLoadResponse)
  ))
_sym_db.RegisterMessage(WaveformLoadResponse)


DESCRIPTOR._options = None

_WAVEFORMLOADINGSERVICE = _descriptor.ServiceDescriptor(
  name='WaveformLoadingService',
  full_name='ai.cogneed.cloud.speech.v1.WaveformLoadingService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=170,
  serialized_end=301,
  methods=[
  _descriptor.MethodDescriptor(
    name='load',
    full_name='ai.cogneed.cloud.speech.v1.WaveformLoadingService.load',
    index=0,
    containing_service=None,
    input_type=_WAVEFORMLOADREQUEST,
    output_type=_WAVEFORMLOADRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WAVEFORMLOADINGSERVICE)

DESCRIPTOR.services_by_name['WaveformLoadingService'] = _WAVEFORMLOADINGSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-ks/services/predict.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.cogneed_ks.models import mfcc_audio_pb2 as cogneed__protos_dot_cogneed__ks_dot_models_dot_mfcc__audio__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-ks/services/predict.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n0cogneed-protos/cogneed-ks/services/predict.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\x1a\x31\x63ogneed-protos/cogneed-ks/models/mfcc_audio.proto\"8\n\x12PredictionResponse\x12\x13\n\x0bprobability\x18\x01 \x01(\x01\x12\r\n\x05label\x18\x02 \x01(\t\"_\n\x11PredictionRequest\x12\x39\n\nmfcc_audio\x18\x01 \x01(\x0b\x32%.ai.cogneed.cloud.speech.v1.MfccAudio\x12\x0f\n\x07version\x18\x02 \x01(\x03\x32z\n\x0ePredictService\x12h\n\x07predict\x12-.ai.cogneed.cloud.speech.v1.PredictionRequest\x1a..ai.cogneed.cloud.speech.v1.PredictionResponseB\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_cogneed__ks_dot_models_dot_mfcc__audio__pb2.DESCRIPTOR,])




_PREDICTIONRESPONSE = _descriptor.Descriptor(
  name='PredictionResponse',
  full_name='ai.cogneed.cloud.speech.v1.PredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='probability', full_name='ai.cogneed.cloud.speech.v1.PredictionResponse.probability', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='ai.cogneed.cloud.speech.v1.PredictionResponse.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=187,
)


_PREDICTIONREQUEST = _descriptor.Descriptor(
  name='PredictionRequest',
  full_name='ai.cogneed.cloud.speech.v1.PredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mfcc_audio', full_name='ai.cogneed.cloud.speech.v1.PredictionRequest.mfcc_audio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='ai.cogneed.cloud.speech.v1.PredictionRequest.version', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=284,
)

_PREDICTIONREQUEST.fields_by_name['mfcc_audio'].message_type = cogneed__protos_dot_cogneed__ks_dot_models_dot_mfcc__audio__pb2._MFCCAUDIO
DESCRIPTOR.message_types_by_name['PredictionResponse'] = _PREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['PredictionRequest'] = _PREDICTIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PredictionResponse = _reflection.GeneratedProtocolMessageType('PredictionResponse', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTIONRESPONSE,
  __module__ = 'cogneed_protos.cogneed_ks.services.predict_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.PredictionResponse)
  ))
_sym_db.RegisterMessage(PredictionResponse)

PredictionRequest = _reflection.GeneratedProtocolMessageType('PredictionRequest', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTIONREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.predict_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.PredictionRequest)
  ))
_sym_db.RegisterMessage(PredictionRequest)


DESCRIPTOR._options = None

_PREDICTSERVICE = _descriptor.ServiceDescriptor(
  name='PredictService',
  full_name='ai.cogneed.cloud.speech.v1.PredictService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=286,
  serialized_end=408,
  methods=[
  _descriptor.MethodDescriptor(
    name='predict',
    full_name='ai.cogneed.cloud.speech.v1.PredictService.predict',
    index=0,
    containing_service=None,
    input_type=_PREDICTIONREQUEST,
    output_type=_PREDICTIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PREDICTSERVICE)

DESCRIPTOR.services_by_name['PredictService'] = _PREDICTSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-ks/models/mfcc_audio.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-ks/models/mfcc_audio.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n1cogneed-protos/cogneed-ks/models/mfcc_audio.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\"\"\n\nMfccWindow\x12\x14\n\x0c\x63oefficients\x18\x01 \x03(\x01\"D\n\tMfccAudio\x12\x37\n\x07windows\x18\x01 \x03(\x0b\x32&.ai.cogneed.cloud.speech.v1.MfccWindowB\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
)




_MFCCWINDOW = _descriptor.Descriptor(
  name='MfccWindow',
  full_name='ai.cogneed.cloud.speech.v1.MfccWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coefficients', full_name='ai.cogneed.cloud.speech.v1.MfccWindow.coefficients', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=115,
)


_MFCCAUDIO = _descriptor.Descriptor(
  name='MfccAudio',
  full_name='ai.cogneed.cloud.speech.v1.MfccAudio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='windows', full_name='ai.cogneed.cloud.speech.v1.MfccAudio.windows', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=185,
)

_MFCCAUDIO.fields_by_name['windows'].message_type = _MFCCWINDOW
DESCRIPTOR.message_types_by_name['MfccWindow'] = _MFCCWINDOW
DESCRIPTOR.message_types_by_name['MfccAudio'] = _MFCCAUDIO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MfccWindow = _reflection.GeneratedProtocolMessageType('MfccWindow', (_message.Message,), dict(
  DESCRIPTOR = _MFCCWINDOW,
  __module__ = 'cogneed_protos.cogneed_ks.models.mfcc_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.MfccWindow)
  ))
_sym_db.RegisterMessage(MfccWindow)

MfccAudio = _reflection.GeneratedProtocolMessageType('MfccAudio', (_message.Message,), dict(
  DESCRIPTOR = _MFCCAUDIO,
  __module__ = 'cogneed_protos.cogneed_ks.models.mfcc_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.MfccAudio)
  ))
_sym_db.RegisterMessage(MfccAudio)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-ks/services/stream_audio.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-ks/services/stream_audio.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n5cogneed-protos/cogneed-ks/services/stream_audio.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\"\'\n\x16InitAudioStreamRequest\x12\r\n\x05token\x18\x01 \x01(\t\",\n\x17InitAudioStreamResponse\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\"B\n\x12StreamAudioRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\"%\n\x13StreamAudioResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"4\n\x15\x45ndAudioStreamRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t2\xe0\x02\n\x12StreamAudioService\x12o\n\x04init\x12\x32.ai.cogneed.cloud.speech.v1.InitAudioStreamRequest\x1a\x33.ai.cogneed.cloud.speech.v1.InitAudioStreamResponse\x12i\n\x06stream\x12..ai.cogneed.cloud.speech.v1.StreamAudioRequest\x1a/.ai.cogneed.cloud.speech.v1.StreamAudioResponse\x12n\n\x08\x66inalize\x12\x31.ai.cogneed.cloud.speech.v1.EndAudioStreamRequest\x1a/.ai.cogneed.cloud.speech.v1.StreamAudioResponseB\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
)




_INITAUDIOSTREAMREQUEST = _descriptor.Descriptor(
  name='InitAudioStreamRequest',
  full_name='ai.cogneed.cloud.speech.v1.InitAudioStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='ai.cogneed.cloud.speech.v1.InitAudioStreamRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=124,
)


_INITAUDIOSTREAMRESPONSE = _descriptor.Descriptor(
  name='InitAudioStreamResponse',
  full_name='ai.cogneed.cloud.speech.v1.InitAudioStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.cloud.speech.v1.InitAudioStreamResponse.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=170,
)


_STREAMAUDIOREQUEST = _descriptor.Descriptor(
  name='StreamAudioRequest',
  full_name='ai.cogneed.cloud.speech.v1.StreamAudioRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='ai.cogneed.cloud.speech.v1.StreamAudioRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.cloud.speech.v1.StreamAudioRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.cloud.speech.v1.StreamAudioRequest.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=238,
)


_STREAMAUDIORESPONSE = _descriptor.Descriptor(
  name='StreamAudioResponse',
  full_name='ai.cogneed.cloud.speech.v1.StreamAudioResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ai.cogneed.cloud.speech.v1.StreamAudioResponse.status', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=277,
)


_ENDAUDIOSTREAMREQUEST = _descriptor.Descriptor(
  name='EndAudioStreamRequest',
  full_name='ai.cogneed.cloud.speech.v1.EndAudioStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='ai.cogneed.cloud.speech.v1.EndAudioStreamRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.cloud.speech.v1.EndAudioStreamRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=331,
)

DESCRIPTOR.message_types_by_name['InitAudioStreamRequest'] = _INITAUDIOSTREAMREQUEST
DESCRIPTOR.message_types_by_name['InitAudioStreamResponse'] = _INITAUDIOSTREAMRESPONSE
DESCRIPTOR.message_types_by_name['StreamAudioRequest'] = _STREAMAUDIOREQUEST
DESCRIPTOR.message_types_by_name['StreamAudioResponse'] = _STREAMAUDIORESPONSE
DESCRIPTOR.message_types_by_name['EndAudioStreamRequest'] = _ENDAUDIOSTREAMREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InitAudioStreamRequest = _reflection.GeneratedProtocolMessageType('InitAudioStreamRequest', (_message.Message,), dict(
  DESCRIPTOR = _INITAUDIOSTREAMREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.InitAudioStreamRequest)
  ))
_sym_db.RegisterMessage(InitAudioStreamRequest)

InitAudioStreamResponse = _reflection.GeneratedProtocolMessageType('InitAudioStreamResponse', (_message.Message,), dict(
  DESCRIPTOR = _INITAUDIOSTREAMRESPONSE,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.InitAudioStreamResponse)
  ))
_sym_db.RegisterMessage(InitAudioStreamResponse)

StreamAudioRequest = _reflection.GeneratedProtocolMessageType('StreamAudioRequest', (_message.Message,), dict(
  DESCRIPTOR = _STREAMAUDIOREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.StreamAudioRequest)
  ))
_sym_db.RegisterMessage(StreamAudioRequest)

StreamAudioResponse = _reflection.GeneratedProtocolMessageType('StreamAudioResponse', (_message.Message,), dict(
  DESCRIPTOR = _STREAMAUDIORESPONSE,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.StreamAudioResponse)
  ))
_sym_db.RegisterMessage(StreamAudioResponse)

EndAudioStreamRequest = _reflection.GeneratedProtocolMessageType('EndAudioStreamRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENDAUDIOSTREAMREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.EndAudioStreamRequest)
  ))
_sym_db.RegisterMessage(EndAudioStreamRequest)


DESCRIPTOR._options = None

_STREAMAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='StreamAudioService',
  full_name='ai.cogneed.cloud.speech.v1.StreamAudioService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=334,
  serialized_end=686,
  methods=[
  _descriptor.MethodDescriptor(
    name='init',
    full_name='ai.cogneed.cloud.speech.v1.StreamAudioService.init',
    index=0,
    containing_service=None,
    input_type=_INITAUDIOSTREAMREQUEST,
    output_type=_INITAUDIOSTREAMRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='stream',
    full_name='ai.cogneed.cloud.speech.v1.StreamAudioService.stream',
    index=1,
    containing_service=None,
    input_type=_STREAMAUDIOREQUEST,
    output_type=_STREAMAUDIORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='finalize',
    full_name='ai.cogneed.cloud.speech.v1.StreamAudioService.finalize',
    index=2,
    containing_service=None,
    input_type=_ENDAUDIOSTREAMREQUEST,
    output_type=_STREAMAUDIORESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMAUDIOSERVICE)

DESCRIPTOR.services_by_name['StreamAudioService'] = _STREAMAUDIOSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-ks/services/mfcc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.cogneed_ks.models import mfcc_audio_pb2 as cogneed__protos_dot_cogneed__ks_dot_models_dot_mfcc__audio__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-ks/services/mfcc.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n-cogneed-protos/cogneed-ks/services/mfcc.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\x1a\x31\x63ogneed-protos/cogneed-ks/models/mfcc_audio.proto\"#\n\x0bMfccRequest\x12\x14\n\x0cwave_content\x18\x01 \x01(\x0c\x32h\n\x0bMfccService\x12Y\n\x07\x63ompute\x12\'.ai.cogneed.cloud.speech.v1.MfccRequest\x1a%.ai.cogneed.cloud.speech.v1.MfccAudioB\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_cogneed__ks_dot_models_dot_mfcc__audio__pb2.DESCRIPTOR,])




_MFCCREQUEST = _descriptor.Descriptor(
  name='MfccRequest',
  full_name='ai.cogneed.cloud.speech.v1.MfccRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wave_content', full_name='ai.cogneed.cloud.speech.v1.MfccRequest.wave_content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=163,
)

DESCRIPTOR.message_types_by_name['MfccRequest'] = _MFCCREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MfccRequest = _reflection.GeneratedProtocolMessageType('MfccRequest', (_message.Message,), dict(
  DESCRIPTOR = _MFCCREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.mfcc_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.MfccRequest)
  ))
_sym_db.RegisterMessage(MfccRequest)


DESCRIPTOR._options = None

_MFCCSERVICE = _descriptor.ServiceDescriptor(
  name='MfccService',
  full_name='ai.cogneed.cloud.speech.v1.MfccService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=165,
  serialized_end=269,
  methods=[
  _descriptor.MethodDescriptor(
    name='compute',
    full_name='ai.cogneed.cloud.speech.v1.MfccService.compute',
    index=0,
    containing_service=None,
    input_type=_MFCCREQUEST,
    output_type=cogneed__protos_dot_cogneed__ks_dot_models_dot_mfcc__audio__pb2._MFCCAUDIO,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_MFCCSERVICE)

DESCRIPTOR.services_by_name['MfccService'] = _MFCCSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.cogneed_ks.services import predict_pb2 as cogneed__protos_dot_cogneed__ks_dot_services_dot_predict__pb2


class PredictServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.predict = channel.unary_unary(
        '/ai.cogneed.cloud.speech.v1.PredictService/predict',
        request_serializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_predict__pb2.PredictionRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_predict__pb2.PredictionResponse.FromString,
        )


class PredictServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def predict(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_PredictServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'predict': grpc.unary_unary_rpc_method_handler(
          servicer.predict,
          request_deserializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_predict__pb2.PredictionRequest.FromString,
          response_serializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_predict__pb2.PredictionResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.cloud.speech.v1.PredictService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.cogneed_ks.services import audio_prediction_pb2 as cogneed__protos_dot_cogneed__ks_dot_services_dot_audio__prediction__pb2


class AudioPredictionServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.predict = channel.stream_stream(
        '/ai.cogneed.cloud.speech.v1.AudioPredictionService/predict',
        request_serializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_audio__prediction__pb2.AudioPredictionRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_audio__prediction__pb2.AudioPredictionResponse.FromString,
        )


class AudioPredictionServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def predict(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AudioPredictionServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'predict': grpc.stream_stream_rpc_method_handler(
          servicer.predict,
          request_deserializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_audio__prediction__pb2.AudioPredictionRequest.FromString,
          response_serializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_audio__prediction__pb2.AudioPredictionResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.cloud.speech.v1.AudioPredictionService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-waveform/services/audio_to_waveform.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-waveform/services/audio_to_waveform.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n@cogneed-protos/cogneed-waveform/services/audio_to_waveform.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\".\n\x0fWaveformRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"\x1f\n\x10WaveformResponse\x12\x0b\n\x03ret\x18\x01 \x01(\x05\x32~\n\x16WaveformStoringService\x12\x64\n\x05store\x12+.ai.cogneed.cloud.speech.v1.WaveformRequest\x1a,.ai.cogneed.cloud.speech.v1.WaveformResponse(\x01\x42\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
)




_WAVEFORMREQUEST = _descriptor.Descriptor(
  name='WaveformRequest',
  full_name='ai.cogneed.cloud.speech.v1.WaveformRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.cogneed.cloud.speech.v1.WaveformRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.cloud.speech.v1.WaveformRequest.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=142,
)


_WAVEFORMRESPONSE = _descriptor.Descriptor(
  name='WaveformResponse',
  full_name='ai.cogneed.cloud.speech.v1.WaveformResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ret', full_name='ai.cogneed.cloud.speech.v1.WaveformResponse.ret', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=175,
)

DESCRIPTOR.message_types_by_name['WaveformRequest'] = _WAVEFORMREQUEST
DESCRIPTOR.message_types_by_name['WaveformResponse'] = _WAVEFORMRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WaveformRequest = _reflection.GeneratedProtocolMessageType('WaveformRequest', (_message.Message,), dict(
  DESCRIPTOR = _WAVEFORMREQUEST,
  __module__ = 'cogneed_protos.cogneed_waveform.services.audio_to_waveform_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.WaveformRequest)
  ))
_sym_db.RegisterMessage(WaveformRequest)

WaveformResponse = _reflection.GeneratedProtocolMessageType('WaveformResponse', (_message.Message,), dict(
  DESCRIPTOR = _WAVEFORMRESPONSE,
  __module__ = 'cogneed_protos.cogneed_waveform.services.audio_to_waveform_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.WaveformResponse)
  ))
_sym_db.RegisterMessage(WaveformResponse)


DESCRIPTOR._options = None

_WAVEFORMSTORINGSERVICE = _descriptor.ServiceDescriptor(
  name='WaveformStoringService',
  full_name='ai.cogneed.cloud.speech.v1.WaveformStoringService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=177,
  serialized_end=303,
  methods=[
  _descriptor.MethodDescriptor(
    name='store',
    full_name='ai.cogneed.cloud.speech.v1.WaveformStoringService.store',
    index=0,
    containing_service=None,
    input_type=_WAVEFORMREQUEST,
    output_type=_WAVEFORMRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WAVEFORMSTORINGSERVICE)

DESCRIPTOR.services_by_name['WaveformStoringService'] = _WAVEFORMSTORINGSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.cogneed_ks.services import stream_audio_pb2 as cogneed__protos_dot_cogneed__ks_dot_services_dot_stream__audio__pb2


class StreamAudioServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.init = channel.unary_unary(
        '/ai.cogneed.cloud.speech.v1.StreamAudioService/init',
        request_serializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_stream__audio__pb2.InitAudioStreamRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_stream__audio__pb2.InitAudioStreamResponse.FromString,
        )
    self.stream = channel.unary_unary(
        '/ai.cogneed.cloud.speech.v1.StreamAudioService/stream',
        request_serializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_stream__audio__pb2.StreamAudioRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_stream__audio__pb2.StreamAudioResponse.FromString,
        )
    self.finalize = channel.unary_unary(
        '/ai.cogneed.cloud.speech.v1.StreamAudioService/finalize',
        request_serializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_stream__audio__pb2.EndAudioStreamRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_stream__audio__pb2.StreamAudioResponse.FromString,
        )


class StreamAudioServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def init(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def stream(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def finalize(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_StreamAudioServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'init': grpc.unary_unary_rpc_method_handler(
          servicer.init,
          request_deserializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_stream__audio__pb2.InitAudioStreamRequest.FromString,
          response_serializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_stream__audio__pb2.InitAudioStreamResponse.SerializeToString,
      ),
      'stream': grpc.unary_unary_rpc_method_handler(
          servicer.stream,
          request_deserializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_stream__audio__pb2.StreamAudioRequest.FromString,
          response_serializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_stream__audio__pb2.StreamAudioResponse.SerializeToString,
      ),
      'finalize': grpc.unary_unary_rpc_method_handler(
          servicer.finalize,
          request_deserializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_stream__audio__pb2.EndAudioStreamRequest.FromString,
          response_serializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_stream__audio__pb2.StreamAudioResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.cloud.speech.v1.StreamAudioService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-ks/services/forward_audio.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-ks/services/forward_audio.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n6cogneed-protos/cogneed-ks/services/forward_audio.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\"Q\n\x13\x46orwardAudioRequest\x12\x11\n\tcaller_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63\x61ller_id_name\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\"*\n\x14\x46orwardAudioResponse\x12\x12\n\nerror_code\x18\x01 \x01(\x01\x32\x87\x01\n\x13\x46orwardAudioService\x12p\n\x07\x63ollect\x12/.ai.cogneed.cloud.speech.v1.ForwardAudioRequest\x1a\x30.ai.cogneed.cloud.speech.v1.ForwardAudioResponse(\x01\x30\x01\x42\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
)




_FORWARDAUDIOREQUEST = _descriptor.Descriptor(
  name='ForwardAudioRequest',
  full_name='ai.cogneed.cloud.speech.v1.ForwardAudioRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='caller_id', full_name='ai.cogneed.cloud.speech.v1.ForwardAudioRequest.caller_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caller_id_name', full_name='ai.cogneed.cloud.speech.v1.ForwardAudioRequest.caller_id_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.cloud.speech.v1.ForwardAudioRequest.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=167,
)


_FORWARDAUDIORESPONSE = _descriptor.Descriptor(
  name='ForwardAudioResponse',
  full_name='ai.cogneed.cloud.speech.v1.ForwardAudioResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_code', full_name='ai.cogneed.cloud.speech.v1.ForwardAudioResponse.error_code', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=211,
)

DESCRIPTOR.message_types_by_name['ForwardAudioRequest'] = _FORWARDAUDIOREQUEST
DESCRIPTOR.message_types_by_name['ForwardAudioResponse'] = _FORWARDAUDIORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ForwardAudioRequest = _reflection.GeneratedProtocolMessageType('ForwardAudioRequest', (_message.Message,), dict(
  DESCRIPTOR = _FORWARDAUDIOREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.forward_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.ForwardAudioRequest)
  ))
_sym_db.RegisterMessage(ForwardAudioRequest)

ForwardAudioResponse = _reflection.GeneratedProtocolMessageType('ForwardAudioResponse', (_message.Message,), dict(
  DESCRIPTOR = _FORWARDAUDIORESPONSE,
  __module__ = 'cogneed_protos.cogneed_ks.services.forward_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.ForwardAudioResponse)
  ))
_sym_db.RegisterMessage(ForwardAudioResponse)


DESCRIPTOR._options = None

_FORWARDAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='ForwardAudioService',
  full_name='ai.cogneed.cloud.speech.v1.ForwardAudioService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=214,
  serialized_end=349,
  methods=[
  _descriptor.MethodDescriptor(
    name='collect',
    full_name='ai.cogneed.cloud.speech.v1.ForwardAudioService.collect',
    index=0,
    containing_service=None,
    input_type=_FORWARDAUDIOREQUEST,
    output_type=_FORWARDAUDIORESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_FORWARDAUDIOSERVICE)

DESCRIPTOR.services_by_name['ForwardAudioService'] = _FORWARDAUDIOSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-ks/services/audio_prediction.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-ks/services/audio_prediction.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n9cogneed-protos/cogneed-ks/services/audio_prediction.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\"_\n\x17\x41udioPredictionResponse\x12\x10\n\x08start_ms\x18\x01 \x01(\x03\x12\x0e\n\x06\x65nd_ms\x18\x02 \x01(\x03\x12\x13\n\x0bprobability\x18\x03 \x01(\x01\x12\r\n\x05label\x18\x04 \x01(\t\"g\n\x16\x41udioPredictionRequest\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\x12\x12\n\nblob_index\x18\x04 \x01(\x03\x32\x90\x01\n\x16\x41udioPredictionService\x12v\n\x07predict\x12\x32.ai.cogneed.cloud.speech.v1.AudioPredictionRequest\x1a\x33.ai.cogneed.cloud.speech.v1.AudioPredictionResponse(\x01\x30\x01\x42\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
)




_AUDIOPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='AudioPredictionResponse',
  full_name='ai.cogneed.cloud.speech.v1.AudioPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_ms', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionResponse.start_ms', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_ms', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionResponse.end_ms', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probability', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionResponse.probability', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionResponse.label', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=184,
)


_AUDIOPREDICTIONREQUEST = _descriptor.Descriptor(
  name='AudioPredictionRequest',
  full_name='ai.cogneed.cloud.speech.v1.AudioPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionRequest.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_version', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionRequest.model_version', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionRequest.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.cloud.speech.v1.AudioPredictionRequest.blob_index', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=289,
)

DESCRIPTOR.message_types_by_name['AudioPredictionResponse'] = _AUDIOPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['AudioPredictionRequest'] = _AUDIOPREDICTIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AudioPredictionResponse = _reflection.GeneratedProtocolMessageType('AudioPredictionResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOPREDICTIONRESPONSE,
  __module__ = 'cogneed_protos.cogneed_ks.services.audio_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.AudioPredictionResponse)
  ))
_sym_db.RegisterMessage(AudioPredictionResponse)

AudioPredictionRequest = _reflection.GeneratedProtocolMessageType('AudioPredictionRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOPREDICTIONREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.audio_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.AudioPredictionRequest)
  ))
_sym_db.RegisterMessage(AudioPredictionRequest)


DESCRIPTOR._options = None

_AUDIOPREDICTIONSERVICE = _descriptor.ServiceDescriptor(
  name='AudioPredictionService',
  full_name='ai.cogneed.cloud.speech.v1.AudioPredictionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=292,
  serialized_end=436,
  methods=[
  _descriptor.MethodDescriptor(
    name='predict',
    full_name='ai.cogneed.cloud.speech.v1.AudioPredictionService.predict',
    index=0,
    containing_service=None,
    input_type=_AUDIOPREDICTIONREQUEST,
    output_type=_AUDIOPREDICTIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUDIOPREDICTIONSERVICE)

DESCRIPTOR.services_by_name['AudioPredictionService'] = _AUDIOPREDICTIONSERVICE

# @@protoc_insertion_point(module_scope)
